@@ -30,6 +30,10 @@ ZEND_API void ZEND_FASTCALL zend_objects_clone_members(zend_object *new_object,
 ZEND_API void zend_object_std_dtor(zend_object *object);
 ZEND_API void zend_objects_destroy_object(zend_object *object);
 ZEND_API zend_object *zend_objects_clone_obj(zend_object *object);
+
+void zend_object_dtor_dynamic_properties(zend_object *object);
+void zend_object_dtor_property(zend_object *object, zval *p);
+
 END_EXTERN_C()
 
 #endif /* ZEND_OBJECTS_H */
